BarcodeData class

Constructors

BarcodeData({required List<CornerPoint> cornerPoints, required int type, required String value})
BarcodeData.fromJson(Map<String, dynamic> json)
factory

Properties

cornerPoints → List<CornerPoint>
final
getType → BarcodeType
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
final
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited